==> activity-center-biz-1.0.2-20160622.061036-30-sources.jar: cn/com/duiba/activity/center/biz/service/impl/ActivityCategoryRelationServiceImpl.java <==
/**
 * Project Name:activity-center-biz
 * File Name:ActivityCategoryRelationServiceImpl.java
 * Package Name:cn.com.duiba.activity.center.biz.service.impl
 * Date:2016年6月8日下午5:07:24
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.activity.center.biz.service.impl;

import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import cn.com.duiba.activity.center.api.dto.CategoryActivityDto;
import cn.com.duiba.activity.center.biz.dao.category.ActivityCategoryRelationDao;
import cn.com.duiba.activity.center.biz.entity.ActivityCategoryRelationEntity;
import cn.com.duiba.activity.center.biz.service.ActivityCategoryRelationService;

/**
 * ClassName:ActivityCategoryRelationServiceImpl <br/>
 * Function: TODO ADD FUNCTION. <br/>
 * Reason:	 TODO ADD REASON. <br/>
 * Date:     2016年6月8日 下午5:07:24 <br/>
 * @author   wubo
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
@Service
public class ActivityCategoryRelationServiceImpl implements ActivityCategoryRelationService{
    private static final Logger log=LoggerFactory.getLogger(ActivityCategoryRelationServiceImpl.class);
    @Autowired
    private ActivityCategoryRelationDao activityCategoryRelationDao;
    @Override
    public List<ActivityCategoryRelationEntity> findByAppCategory(long appId, long categoryId) {
        return this.activityCategoryRelationDao.selectByAppCategory(appId, categoryId);
    }
    @Override
    @Transactional
    public boolean sortActivities(List<CategoryActivityDto> activities) {
        boolean rs = true;
        try{
            for(CategoryActivityDto dto:activities){
                if(1==this.activityCategoryRelationDao.updatePayload(dto.getId(), dto.getPayload())){
                    continue;
                }else{
                    rs = false;
                }
            }
        }catch(Exception e){
            rs = false;
            log.error("更新权重值出错",e);
        }
        
        return rs;
    }

}

==> activity-center-biz-1.1.3-20160719.030755-1-sources.jar: cn/com/duiba/activity/center/biz/service/impl/ActivityCategoryRelationServiceImpl.java <==
/**
 * Project Name:activity-center-biz
 * File Name:ActivityCategoryRelationServiceImpl.java
 * Package Name:cn.com.duiba.activity.center.biz.service.impl
 * Date:2016年6月8日下午5:07:24
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.activity.center.biz.service.impl;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import cn.com.duiba.activity.center.api.dto.CategoryActivityDto;
import cn.com.duiba.activity.center.biz.dao.DsConstants;
import cn.com.duiba.activity.center.biz.dao.category.ActivityCategoryRelationDao;
import cn.com.duiba.activity.center.biz.entity.ActivityCategoryRelationEntity;
import cn.com.duiba.activity.center.biz.service.ActivityCategoryRelationService;

/**
 * ClassName:ActivityCategoryRelationServiceImpl <br/>
 * Date:     2016年6月8日 下午5:07:24 <br/>
 * @author   wubo
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
@Service
@Transactional(DsConstants.DATABASE_CREDITS_ACTIVITY)
public class ActivityCategoryRelationServiceImpl implements ActivityCategoryRelationService{
    private static final Logger log=LoggerFactory.getLogger(ActivityCategoryRelationServiceImpl.class);
    @Autowired
    private ActivityCategoryRelationDao activityCategoryRelationDao;
    @Override
    public List<ActivityCategoryRelationEntity> findByAppCategory(long appId, long categoryId) {
        return this.activityCategoryRelationDao.selectByAppCategory(appId, categoryId);
    }
    @Override
    public boolean sortActivities(List<CategoryActivityDto> activities) {
        boolean rs = true;
        try{
            for(CategoryActivityDto dto:activities){
                if(1==this.activityCategoryRelationDao.updatePayload(dto.getId(), dto.getPayload())){
                    continue;
                }else{
                    rs = false;
                }
            }
        }catch(Exception e){
            rs = false;
            log.error("更新权重值出错",e);
        }
        return rs;
    }
    @Override
    public boolean save(ActivityCategoryRelationEntity entity) {
        boolean success = false;
        int rs = this.activityCategoryRelationDao.insert(entity);
        if(rs==1){
            success=true;
        }
        return success;
    }
    @Override
    public boolean remove(long operatingActivityId) {
        boolean rs = false;
        try{
            this.activityCategoryRelationDao.deleteByOperatingActivityId(operatingActivityId);
            rs = true;
        } catch(Exception e){
            log.error("activityCategoryRelationDao.deleteByOperatingActivityId("+operatingActivityId+") error",e);
            throw e;
        }
        return rs;
    }
    @Override
    public ActivityCategoryRelationEntity findByOperatingActivityId(long operatingActivityId) {
        ActivityCategoryRelationEntity entity = new ActivityCategoryRelationEntity();
        entity.setOperatingActivityId(operatingActivityId);
        List<ActivityCategoryRelationEntity> list = this.activityCategoryRelationDao.selectWithConditions(entity);
        if(list!=null&&list.size()>0){
            return list.get(0);
        } else {
            return null;
        }
    }
	@Override
	public List<ActivityCategoryRelationEntity> findByAppCategory(long appId,
			long categoryId, int start, int pageSize) {
		return this.activityCategoryRelationDao.selectByAppCategory(appId, categoryId,start,pageSize);
	}

}
